pub struct MultivariateDensity<T, D>(/* private fields */)
where
T: Scalar,
D: Dim,
DefaultAllocator: Allocator<D>;Expand description
A D-dimensional distribution where each dimension is
independent with potentially different univariate distributions. This is a product distribution:
- Each marginal follows one of the available univariate distributions (Normal, Uniform, Cosine, etc.)
- The joint density is the product of marginals: f(x₁, …, xₐ) = f₁(x₁) × … × fₐ(xₐ)
Construction & Examples
Create a mixed 3D distribution (Normal × Uniform × Constant):
let marginals = SVector::from([
NormalDensity::new(0.0, 1.0, None, None).unwrap().into(),
UniformDensity::new(-1.0, 1.0).unwrap().into(),
ConstantDensity::new(2.0).into(),
]);
let _dist = MultivariateDensity::<f64, Const<3>>::new(marginals);Create a 5D distribution with mixed univariates:
let mvpdf = MultivariateDensity::<f64, Const<5>>::new(SVector::from([
ConstantDensity::new(1.0).into(),
CosineDensity::new(0.1, 0.2).unwrap().into(),
LogUniformDensity::new(0.1, 0.5).unwrap().into(),
NormalDensity::new(0.1, 0.25, Some(-0.5), Some(1.5)).unwrap().into(),
UniformDensity::new(1.0, 2.0).unwrap().into(),
]));Evaluate density at a point:
let marginals = SVector::from([
NormalDensity::new(0.0, 1.0, None, None).unwrap().into(),
UniformDensity::new(-1.0, 1.0).unwrap().into(),
]);
let dist = MultivariateDensity::<f64, U2>::new(marginals);
let sample = SVector::from([0.0, 0.5]);
// Use the Density trait to evaluate - see crate::Density for usage patterns
if let Some(dens) = (&dist).density::<U1, U2>(&sample.as_view()) {
println!("Joint density: {}", dens);
}Sample from the distribution:
let marginals = SVector::from([
NormalDensity::new(0.0, 1.0, None, None).unwrap().into(),
UniformDensity::new(-1.0, 1.0).unwrap().into(),
]);
let dist = MultivariateDensity::<f64, U2>::new(marginals);
let mut rng = StdRng::seed_from_u64(42);
if let Some(sample) = (&dist).sample(&mut rng, &SamplingMode::default()) {
println!("Generated sample: {:?}", sample);
}Implementations
Sourceimpl<T, D> MultivariateDensity<T, D>
impl<T, D> MultivariateDensity<T, D>
Sourcepub fn new(domains: OVector<UnivariateDensity<T>, D>) -> Self
pub fn new(domains: OVector<UnivariateDensity<T>, D>) -> Self
Create a new MultivariateDensity from a vector of UnivariateDensitys.
Sourcepub fn marginals(&self) -> &OVector<UnivariateDensity<T>, D>
pub fn marginals(&self) -> &OVector<UnivariateDensity<T>, D>
Return a reference to the underlying vector of UnivariateDensitys.